@@ -16,6 +16,14 @@
  *
  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
  */
 
 #include <babeltrace/ctf-text/types.h>
@@ -23,8 +31,9 @@
 #include <inttypes.h>
 #include <stdint.h>
 #include <babeltrace/bitfield.h>
+#include <babeltrace/trace-debug-info.h>
 
-int ctf_text_integer_write(struct stream_pos *ppos, struct definition *definition)
+int ctf_text_integer_write(struct bt_stream_pos *ppos, struct bt_definition *definition)
 {
 	struct definition_integer *integer_definition =
 		container_of(definition, struct definition_integer, p);
@@ -43,7 +52,7 @@ int ctf_text_integer_write(struct stream_pos *ppos, struct definition *definitio
 	fprintf(pos->fp, " ");
 	if (pos->print_names)
 		fprintf(pos->fp, "%s = ",
-			g_quark_to_string(definition->name));
+			rem_(g_quark_to_string(definition->name)));
 
 	if (pos->string
 	    && (integer_declaration->encoding == CTF_STRING_ASCII
@@ -92,10 +101,20 @@ int ctf_text_integer_write(struct stream_pos *ppos, struct definition *definitio
 	{
 		uint64_t v;
 
-		if (!integer_declaration->signedness)
+		if (!integer_declaration->signedness) {
 			v = integer_definition->value._unsigned;
-		else
+		} else {
 			v = (uint64_t) integer_definition->value._signed;
+			if (integer_declaration->len < 64) {
+				size_t len = integer_declaration->len;
+			        size_t rounded_len;
+
+				assert(len != 0);
+				/* Round length to the nearest 3-bit */
+				rounded_len = (((len - 1) / 3) + 1) * 3;
+				v &= ((uint64_t) 1 << rounded_len) - 1;
+			}
+		}
 
 		fprintf(pos->fp, "0%" PRIo64, v);
 		break;
@@ -104,10 +123,18 @@ int ctf_text_integer_write(struct stream_pos *ppos, struct definition *definitio
 	{
 		uint64_t v;
 
-		if (!integer_declaration->signedness)
+		if (!integer_declaration->signedness) {
 			v = integer_definition->value._unsigned;
-		else
+		} else {
 			v = (uint64_t) integer_definition->value._signed;
+			if (integer_declaration->len < 64) {
+				/* Round length to the nearest nibble */
+				uint8_t rounded_len =
+					((integer_declaration->len + 3) & ~0x3);
+
+				v &= ((uint64_t) 1 << rounded_len) - 1;
+			}
+		}
 
 		fprintf(pos->fp, "0x%" PRIX64, v);
 		break;
@@ -116,5 +143,7 @@ int ctf_text_integer_write(struct stream_pos *ppos, struct definition *definitio
 		return -EINVAL;
 	}
 
+	ctf_text_integer_write_debug_info(ppos, definition);
+
 	return 0;
 }
